==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/components/table/DropDown.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/components/table/DropDown.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/drop-down', '@frontend-taglib-clay$clayui/icon', 'frontend-js-react-web$react', '../button/Button.es', './DropDownAction.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _dropDown = _interopRequireWildcard(require("@frontend-taglib-clay$clayui/drop-down"));

  var _icon = _interopRequireDefault(require("@frontend-taglib-clay$clayui/icon"));

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _Button = _interopRequireDefault(require("../button/Button.es"));

  var _DropDownAction = _interopRequireDefault(require("./DropDownAction.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj["default"] = obj;return newObj;
    }
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var ItemList = _dropDown["default"].ItemList;

  var _default = function _default(_ref) {
    var actions = _ref.actions,
        item = _ref.item;

    var _useState = (0, _react.useState)(false),
        _useState2 = _slicedToArray(_useState, 2),
        active = _useState2[0],
        setActive = _useState2[1];

    var DropdownButton = _react["default"].createElement(_Button["default"], {
      className: "page-link",
      displayType: "unstyled"
    }, _react["default"].createElement(_icon["default"], {
      symbol: "ellipsis-v"
    }));

    actions = actions.filter(function (action) {
      return action.show ? action.show(item) : true;
    });

    if (actions.length === 0) {
      return DropdownButton;
    }

    return _react["default"].createElement(_dropDown["default"], {
      active: active,
      alignmentPosition: _dropDown.Align.RightCenter,
      className: "dropdown-action",
      onActiveChange: function onActiveChange(newVal) {
        return setActive(newVal);
      },
      trigger: DropdownButton
    }, _react["default"].createElement(ItemList, null, actions.map(function (action, index) {
      return _react["default"].createElement(_DropDownAction["default"], {
        action: action,
        item: item,
        key: index,
        setActive: setActive
      });
    })));
  };

  exports["default"] = _default;
  //# sourceMappingURL=DropDown.es.js.map
});
//# sourceMappingURL=DropDown.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/components/table/DropDown.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/components/table/DropDown.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/drop-down', '@frontend-taglib-clay$clayui/icon', 'frontend-js-react-web$react', '../button/Button.es', './DropDownAction.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _dropDown = _interopRequireWildcard(require("@frontend-taglib-clay$clayui/drop-down"));

  var _icon = _interopRequireDefault(require("@frontend-taglib-clay$clayui/icon"));

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _Button = _interopRequireDefault(require("../button/Button.es"));

  var _DropDownAction = _interopRequireDefault(require("./DropDownAction.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var ItemList = _dropDown["default"].ItemList;

  var _default = function _default(_ref) {
    var actions = _ref.actions,
        item = _ref.item;

    var _useState = (0, _react.useState)(false),
        _useState2 = _slicedToArray(_useState, 2),
        active = _useState2[0],
        setActive = _useState2[1];

    var DropdownButton = _react["default"].createElement(_Button["default"], {
      className: "page-link",
      displayType: "unstyled"
    }, _react["default"].createElement(_icon["default"], {
      symbol: "ellipsis-v"
    }));

    actions = actions.filter(function (action) {
      return action.show ? action.show(item) : true;
    });

    if (actions.length === 0) {
      return DropdownButton;
    }

    return _react["default"].createElement(_dropDown["default"], {
      active: active,
      alignmentPosition: _dropDown.Align.RightCenter,
      className: "dropdown-action",
      onActiveChange: function onActiveChange(newVal) {
        return setActive(newVal);
      },
      trigger: DropdownButton
    }, _react["default"].createElement(ItemList, null, actions.map(function (action, index) {
      return _react["default"].createElement(_DropDownAction["default"], {
        action: action,
        item: item,
        key: index,
        setActive: setActive
      });
    })));
  };

  exports["default"] = _default;
  //# sourceMappingURL=DropDown.es.js.map
});
//# sourceMappingURL=DropDown.es.js.map
